{% extends 'base.html' %}
{% load i18n %}
{% load url from future %}

{% block title %}{% trans 'Alarms' %}{% endblock %}
{% block page_header %}
  {% if service != 'all'%}
    <div class="page-header">
      <h2>{% trans 'Alarms for ' %} {{ service }}</h2>
    </div>
   {% else %}
  {% include "horizon/common/_page_header.html" with title=_("All Alarms") %}
  {% endif %}
{% endblock page_header %}

{% block breadcrumb_nav %}
  <ol class="breadcrumb">
    <li class="breadcrumb-item-truncate">{% trans "Monitoring" %}</li>
    <li class="breadcrumb-item-truncate active">{% trans "Alarms" %}</li>
  </ol>
{% endblock %}

{% block main %}
    {{ table.render }}
<div class="pagination">
    <span class="step-links">
        {% if prev_page_offset != None %}
            <a href="?page_offset={{ prev_page_offset }}" class="btn btn-default btn-sm" style="position:relative;top:-35px;">{% trans 'Previous Page' %}</a>
        {% endif %}
        {% if page_offset %}
            <a href="?page_offset={{ page_offset}}" class="btn btn-default btn-sm" style="position:relative;top:-35px;">{% trans 'Next Page' %}</a>
        {% endif %}
    </span>
</div>
{% endblock %}
